import opensim as osim
import math

pi        = math.pi
backl     = 0.6
uarml     = 0.25

bbaan = osim.Model()
bbaan.setName("BootBaan")
bbaan.setGravity(osim.Vec3(0, -9.90665, 0))

lowerb = osim.Body("Back",
                   10,
                   osim.Vec3(0, 0, 0),
                   osim.Inertia(1, 1, 1))
lowerbGeometry = osim.Brick(osim.Vec3(0.04, backl/2, 0.08))
lowerb.attachGeometry(lowerbGeometry)
lowerbGeometry.setColor(osim.Vec3(1, 1, 1))
bbaan.addBody(lowerb)

upperal = osim.Body("Upper_Arm_Left",
                    5,
                    osim.Vec3(0, 0, 0),
                    osim.Inertia(1, 1, 1))
upperalGeometry = osim.Brick(osim.Vec3(0.04, uarml/2, 0.04))
upperal.attachGeometry(upperalGeometry)
upperalGeometry.setColor(osim.Vec3(1, 1, 1))
bbaan.addBody(upperal)

lbackJoint = osim.PinJoint("lbackJoint",
                           bbaan.getGround(),
                           osim.Vec3(0, 0, 0),
                           osim.Vec3(0, 0, 0),
                           lowerb,
                           osim.Vec3(0, -backl/2, 0),
                           osim.Vec3(0, 0, 0))
bbaan.addJoint(lbackJoint)
coord = lbackJoint.updCoordinate()
coord.setName('lbackangle')
coord.setDefaultValue(math.radians(-35))

act = osim.CoordinateActuator('lbackangle')
act.setName('lbackact')
bbaan.addForce(act)

uarmlJoint = osim.BallJoint("upper_arm_left_Joint",
                            lowerb,
                            osim.Vec3(0, backl/2, 0),
                            osim.Vec3(0, 0, pi/2),
                            upperal,
                            osim.Vec3(0, -uarml/2, 0),
                            osim.Vec3(0, 0, 0))
bbaan.addJoint(uarmlJoint)
coord = uarmlJoint.upd_coordinates(0)
coord.setName('uarmleft_out')
coord.setDefaultValue(math.radians(-14.27))
coord = uarmlJoint.upd_coordinates(1)
coord.setName('uarmleft_trn')
coord.setDefaultValue(math.radians(-16.08))
coord = uarmlJoint.upd_coordinates(2)
coord.setName('uarmleft_up')
coord.setDefaultValue(math.radians(45.9))

act = osim.CoordinateActuator('uarmleft_out')
act.setName('ualo_act')
bbaan.addForce(act)
act = osim.CoordinateActuator('uarmleft_trn')
act.setName('ualt_act')
bbaan.addForce(act)
act = osim.CoordinateActuator('uarmleft_up')
act.setName('ualu_act')
bbaan.addForce(act)

reporter = osim.ConsoleReporter()
reporter.set_report_time_interval(1.0)
bbaan.addComponent(reporter)

bbaan.finalizeConnections()
bbaan.printToXML("BootBaan_noarms.osim")

